﻿/*
 * FILE:        PointEqualityComparer.cs
 *                                                                      
 * DESCRIPTION: The file contains implementation comparing the equality of two instances of 'Point'.
 *
 * VERSION:     v1.0, updated July 2011.
 *
 * Copyright © 2011 Microsoft Corporation. All rights reserved.
 */

using System;
using System.Collections.Generic;

namespace Research.MapReduce.Samples.KMeansClustering
{
    /// <summary>
    /// Compares the equality of two instances of <see cref="Research.MapReduce.Samples.KMeansClustering.Point"/>.
    /// </summary>
    public class PointEqualityComparer : IEqualityComparer<Point>
    {
        #region Fields

        private const int pointComparisonPrecisionInDigits = 1;

        #endregion

        #region Methods

        /// <summary>
        /// Checks two instances of <see cref="Research.MapReduce.Samples.KMeansClustering.Point" /> for
        /// equality.
        /// </summary>
        /// <param name="first">First <see cref="Research.MapReduce.Samples.KMeansClustering.Point" /> 
        /// to be compared.</param>
        /// <param name="second">Second <see cref="Research.MapReduce.Samples.KMeansClustering.Point" /> 
        /// to be compared.</param>
        /// <returns>a Boolean value which is True if both inputs are equal, False otherwise.</returns>
        public bool Equals(Point first, Point second)
        {
            return Math.Round(first.X, pointComparisonPrecisionInDigits) == Math.Round(second.X,
                    pointComparisonPrecisionInDigits) &&
                   Math.Round(first.Y, pointComparisonPrecisionInDigits) == Math.Round(second.Y,
                    pointComparisonPrecisionInDigits);
        }

        /// <summary>
        /// Calculates and returns the hash code of the specified <see cref="Research.MapReduce.Samples.
        /// KMeansClustering.Point" /> object.
        /// </summary>
        /// <param name="obj">The <see cref="Research.MapReduce.Samples.KMeansClustering.Point" /> object
        /// whose hash code is to be calculated.</param>
        /// <returns>The integer hash code of the point.</returns>
        public int GetHashCode(Point obj)
        {
            return Convert.ToInt32((obj.X + obj.Y) % (double)int.MaxValue);
        }

        #endregion
    }
}