﻿//------------------------------------------------------------------------------------------------- 
// <copyright file="AttributeValueFrequencyRecord.cs" company="Microsoft">
// Copyright (c) Microsoft. All rights reserved.
// </copyright>
//-------------------------------------------------------------------------------------------------

namespace Research.MapReduce.Samples.OutlierDetection
{
    using System;
    using System.Diagnostics.CodeAnalysis;
    using System.Globalization;

    /// <summary>
    /// Used to store a record with AVF score.
    /// </summary>
    [SuppressMessage("Microsoft.Design", "CA1036:OverrideMethodsOnComparableTypes", Justification = "Not needed."), Serializable]
    public class AttributeValueFrequencyRecord : IComparable<AttributeValueFrequencyRecord>
    {
        /// <summary>
        /// Initializes a new instance of the AttributeValueFrequencyRecord class.
        /// </summary>
        /// <param name="value">Value of the row.</param>
        /// <param name="attributeValueFrequencyScore">AVF score of the row.</param>
        public AttributeValueFrequencyRecord(string value, int attributeValueFrequencyScore)
        {
            this.Value = value;
            this.AttributeValueFrequencyScore = attributeValueFrequencyScore;
        }

        /// <summary>
        /// Gets or sets the value of the row.
        /// </summary>
        public string Value { get; set; }

        /// <summary>
        /// Gets or sets the value of the row.
        /// </summary>
        public int AttributeValueFrequencyScore { get; set; }

        /// <summary>
        /// Compares the current object with another object of the same type.
        /// </summary>
        /// <param name="other">Other object.</param>
        /// <returns>Value that indicates whether the current object is lesser, equal or greater than the parameter.</returns>
        public int CompareTo(AttributeValueFrequencyRecord other)
        {
            if (other == null)
            {
                return 1;
            }

            return string.CompareOrdinal(this.Value, other.Value);
        }

        /// <summary>
        /// Overriding .ToString() method.
        /// </summary>
        /// <returns>String format of the object.</returns>
        public override string ToString()
        {
            return string.Format(CultureInfo.InvariantCulture, "{0},{1}", this.Value, this.AttributeValueFrequencyScore);
        }
    }
}