﻿//------------------------------------------------------------------------------------------------- 
// <copyright file="FindOutliersReducer.cs" company="Microsoft">
// Copyright (c) Microsoft. All rights reserved.
// </copyright>
//-------------------------------------------------------------------------------------------------

namespace Research.MapReduce.Samples.OutlierDetection
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using Research.MapReduce.Core;
    using Research.MapReduce.Samples.OutlierDetection.Properties;

    /// <summary>
    /// Return the final outliers.
    /// </summary>
    public sealed class FindOutliersReducer : IReducer<int, AttributeValueFrequencyRecord, int, string>
    {
        /// <summary>
        /// Number of outliers need to be displayed in the output.
        /// </summary>
        private int numberOfOutliers;

        /// <summary>
        /// Configure Reducer.
        /// </summary>
        /// <param name="context">ReduceContext to get the user inputs.</param>
        public void Configure(ReduceContext<int, AttributeValueFrequencyRecord> context)
        {
            if (context == null)
            {
                throw new ArgumentNullException("context", Resources.MapContextCannotBeNull);
            }

            if (!int.TryParse(context.JobParameters[ParameterNames.NumberOfOutliers], out this.numberOfOutliers) || this.numberOfOutliers <= 0)
            {
                throw new ArgumentException(Resources.NumberOfOutliersShouldBeGreaterThanZero);
            }
        }

        /// <summary>
        /// No records are filtered in this method.
        /// </summary>
        /// <param name="key">Integer key.</param>
        /// <param name="values">Values with the same key.</param>
        /// <param name="context">ReduceContext to get the user inputs.</param>
        /// <returns>output of match filter operator.</returns>
        public IEnumerable<KeyValuePair<int, string>> Reduce(int key, IEnumerable<AttributeValueFrequencyRecord> values, ReduceContext<int, AttributeValueFrequencyRecord> context)
        {
            return values.OrderBy(v => v.AttributeValueFrequencyScore).Take(this.numberOfOutliers).Select(v => new KeyValuePair<int, string>(key, v.ToString()));
        }
    }
}