﻿//------------------------------------------------------------------------------------------------- 
// <copyright file="MethodExtensions.cs" company="Microsoft">
// Copyright (c) Microsoft. All rights reserved.
// </copyright>
//-------------------------------------------------------------------------------------------------

namespace Research.MapReduce.Samples.OutlierDetection
{
    using System;
    using System.Globalization;
    using System.Text;
    using Microsoft.WindowsAzure.StorageClient;

    /// <summary>
    /// Contains common purpose extension methods.
    /// </summary>
    internal static class MethodExtensions
    {
        #region Methods

        /// <summary>
        /// Validates that the string is a well-formed uri. Throws an exception if the input
        /// string is not a well-formed uri.
        /// </summary>
        /// <param name="uri">String to be validated.</param>
        /// <param name="uriParamName">Name of the parameter.</param>
        /// <exception cref="System.ArgumentException"/>
        public static void ValidateUriFormat(this string uri, string uriParamName)
        {
            if (!Uri.IsWellFormedUriString(uri, UriKind.Absolute))
            {
                throw new ArgumentException(
                    string.Format(CultureInfo.InvariantCulture, "Value [{0}] specified for [{1}] is not a valid uri.", uri, uriParamName));
            }
        }

        /// <summary>
        /// Deletes all the blobs in the specified blob container.
        /// </summary>
        /// <param name="container">Blob container which is to be cleaned.</param>
        public static void CleanIfExist(this CloudBlobContainer container)
        {
            foreach (CloudBlob blob in container.ListBlobs(new BlobRequestOptions
            {
                UseFlatBlobListing = true
            }))
            {
                blob.Delete();
            }
        }

        /// <summary>
        /// Converts a string array to a single string by concatinating them with a space between
        /// them.
        /// </summary>
        /// <param name="strArray">Array containing the strings that need to be concatinated.</param>
        /// <returns>Concatinated string representing the input string array.</returns>
        public static string GetString(this string[] strArray)
        {
            StringBuilder builder = new StringBuilder();
            foreach (string str in strArray)
            {
                builder.AppendFormat("{0} ", str);
            }

            return builder.ToString().TrimEnd();
        }

        #endregion
    }
}